gsheetplus.alloy.api


kw-or-strclj

(kw-or-str x)

read-dataclj

(read-data service spreadsheet-id range)

range can just be a Tab name, for all data.

`range` can just be a Tab name, for all data.
raw docstring

renderclj

(render zipper context-map extensions)

Render the nodes of the zipper using the standard parser.

  • zipper is a clojure.zip structure.
  • context-map is a data structure to use for REF lookup.
  • extensions (nilable) is a Map of filters and custom-tags. {:filters {:upper-case (fn [x] (.toUpperCase x)) :embiginate clojure.string/upper-case ; With arguments: :plus2 (fn [node-val & args] (apply + node-val 2 args))} :inline-ctags {:key-count (fn [context-map] (count (keys context-map)))}}
Render the nodes of the zipper using the standard parser.
- zipper is a clojure.zip structure.
- context-map is a data structure to use for REF lookup.
- extensions (nilable) is a Map of filters and custom-tags.
  {:filters {:upper-case (fn [x] (.toUpperCase x))
             :embiginate clojure.string/upper-case
             ; With arguments:
             :plus2 (fn [node-val & args] (apply + node-val 2 args))}
   :inline-ctags {:key-count (fn [context-map] (count (keys context-map)))}}
raw docstring

render-google-sheetclj

(render-google-sheet gsheet-service
                     spreadsheet-id
                     sheet-name
                     context-map
                     extensions)

Render the google sheet using the given context-map. Returns a Map of keys :errors, :spreadsheet-id and :sheet-id

Render the google sheet using the given context-map.
Returns a Map of keys :errors, :spreadsheet-id and :sheet-id
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries