gsheetplus.alloy.grammar


ast-node?clj

(ast-node? x)

grammarclj


mkastnodeclj

(mkastnode op path & {:as kvs})

normalize-astclj

(normalize-ast insta-seq path)

Convert the parsed units into Records. The original (instaparse) metadata is retained.

Convert the parsed units into Records. The original (instaparse) metadata is retained.
raw docstring

number-formatclj


parse-structclj

(parse-struct parser zipper)

the-parserclj


vec-indexclj

(vec-index node)

zipper-mapclj

(zipper-map f zipper)

Apply the function, f, to each loc and node value in the zipper.

Apply the function, f, to each loc and node value in the zipper.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries