gsheetplus.alloy.render


ast-zipclj

(ast-zip root)

Returns a zipper for nested vectors, given a root vector/seq. This is more forgiving than clojure.zip/vector-zip and accepts seqs or vectors as branches. We need this (for our second pass, the one on the AST) b/c our incoming templates are vector trees, but instaparse returns seqs.

Returns a zipper for nested vectors, given a root vector/seq.
This is more forgiving than clojure.zip/vector-zip and accepts
seqs or vectors as branches.
We need this (for our second pass, the one on the AST) b/c our
incoming templates are vector trees, but instaparse returns seqs.
raw docstring

eval-error?clj

(eval-error? x)

evaluateclj

(evaluate extensions context-map level-stack x)

extend-sizeclj

(extend-size target-count default-value coll)

Extend collection to be at least target-count in length. Extra values concatenated on the end will have value default-value.

Extend collection to be at least `target-count` in length. Extra values concatenated
on the end will have value `default-value`.
raw docstring

filter-astclj

(filter-ast x)

handlecljmultimethod


inc-lastclj

(inc-last indexes)

inline-f-err-handlerclj

(inline-f-err-handler node level-stack thunk)

mk-handledclj

(mk-handled & {:as m})

new-render-stateclj

(new-render-state context-map)

rc-errorclj

(rc-error node fmt-msg & format-args)

render-astclj

(render-ast context-map extensions ast)

rewind-to-bookmarkclj

(rewind-to-bookmark zipper bookmark)

row->itemsclj

(row->items loop-depth row)

Pull value from the collector of each cell-seq item, based on the indices. If the cell value is a literal just use the value as is.

Pull value from the collector of each cell-seq item, based on the indices. If the cell
value is a literal just use the value as is.
raw docstring

set-bookmarkclj

(set-bookmark loc bookmark)

single-or-reduce-strclj

(single-or-reduce-str coll)

str-join-collectorsclj

(str-join-collectors loop-depth collectors)

Within each cell, combine (str join) the collector values at each set of loop indices. Example: loop-depth = 2 collectors = [ [ [10 20] [10 20] [10 20]] ; (a) ['[a a] '[b b] '[c c]] ] ; (b) => [ ["10a" "20a"] ["10b" "20b"] ["10c" "20c"] ] This is:

  1. Two Nodes in each cell, (a) and (b)
  2. Outer loop length 3
  3. Inner loop length 2
Within each cell, combine (str join) the collector values at each set of loop indices.
Example:
  loop-depth = 2
  collectors =
    [ [ [10 20] [10 20] [10 20]]       ; (a)
      ['[a a]  '[b b]  '[c c]]   ]     ; (b)
  =>
  [ ["10a" "20a"]
    ["10b" "20b"]
    ["10c" "20c"] ]
This is:
  1. Two Nodes in each cell, (a) and (b)
  2. Outer loop length 3
  3. Inner loop length 2
raw docstring

tagnameclj

(tagname tag-key)

template-errclj

(template-err msg state-stack loc)

unrollclj

(unroll rows)

unroll*clj

(unroll* loop-depth [row & remaining])

validate-state-level!clj

(validate-state-level! state level-stack expected-start-tag node)

vec-append-atclj

(vec-append-at coll loop-indices value context-string)

cljdoc builds & hosts documentation for Clojure/Script libraries