gsheetplus.cell

Cell data protocol and conversions between Clojure values and Google Sheets API types. Extend CellDataValue for custom write-time type coercions.

Cell data protocol and conversions between Clojure values and Google Sheets API types.
Extend CellDataValue for custom write-time type coercions.
raw docstring

cell->cljclj

(cell->clj cell-data)

Convert a raw Google Sheets API cell map to a Clojure value. Handles effectiveValue / userEnteredValue; prefers effectiveValue. Types: boolValue → Boolean, stringValue → String, DATE number → LocalDate, CURRENCY number → BigDecimal, number → Double, empty → nil.

Convert a raw Google Sheets API cell map to a Clojure value.
Handles effectiveValue / userEnteredValue; prefers effectiveValue.
Types: boolValue → Boolean, stringValue → String, DATE number → LocalDate,
       CURRENCY number → BigDecimal, number → Double, empty → nil.
raw docstring

CellDataValuecljprotocol

Coerce a Clojure value to a CellData instance for writing to Google Sheets.

Coerce a Clojure value to a CellData instance for writing to Google Sheets.

->cell-dataclj

(->cell-data v)
raw docstring

date-cellclj

(date-cell pattern local-date)

CellData containing local-date formatted with the given Excel date pattern, e.g. "yyyy-mm-dd" or "M/d/yyyy".

CellData containing `local-date` formatted with the given Excel date pattern,
e.g. "yyyy-mm-dd" or "M/d/yyyy".
raw docstring

date-serial-numberclj

(date-serial-number local-date)

Google Sheets date serial number for a java.time.LocalDate. Days since 1899-12-30, returned as Double.

Google Sheets date serial number for a java.time.LocalDate.
Days since 1899-12-30, returned as Double.
raw docstring

row->row-dataclj

(row->row-data row)

Convert a vector of values (anything satisfying CellDataValue) to a RowData instance for use in UpdateCellsRequest.

Convert a vector of values (anything satisfying CellDataValue) to a RowData
instance for use in UpdateCellsRequest.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries