gsheetplus.extras


gcreds-stream-from-aws-secrets-managerclj

(gcreds-stream-from-aws-secrets-manager aws secret-id)

Get the Google api keys from the secrets Map, as a Stream. The Google API client library we're using expects the creds to be either a separate file or a Stream. Creating the stream this way, allows us to embed the API creds in the common secrets file.

Get the Google api keys from the `secrets` Map, as a Stream. The Google
API client library we're using expects the creds to be either a separate file
or a Stream. Creating the stream this way, allows us to embed the API creds
in the common `secrets` file.
raw docstring

login-with-aws-secretclj

(login-with-aws-secret aws secret-id)

set-timeoutclj

(set-timeout request-initializer connection-timeout-millis read-timeout-millis)

The credentials, e.g. (GoogleCredential/fromStream creds-stream transport factory) can be used for the request-initializer.

The credentials, e.g. (GoogleCredential/fromStream creds-stream transport factory)
can be used for the request-initializer.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries