(ast-node? x)(mkastnode op path & {:as kvs})(normalize-ast insta-seq path)Convert the parsed units into Records. The original (instaparse) metadata is retained.
Convert the parsed units into Records. The original (instaparse) metadata is retained.
(parse-struct parser zipper)(vec-index node)(zipper-map f zipper)Apply the function, f, to each loc and node value in the zipper.
Apply the function, f, to each loc and node value in the zipper.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |